
#ifndef HAVE_gdhcpd_H
#   define HAVE_gdhcpd_H

extern struct w *widgets;

int main(int argc, char *argv[]);

#endif
